<!DOCTYPE html>
<html <?php language_attributes(); ?>>
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=<?php bloginfo( 'charset' ); ?>">
		<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
		<meta name="viewport" content="width=device-width, initial-scale=1">

		<meta name="theme-color" content="#141416">
		<meta name="msapplication-navbutton-color" content="#141416">
		<meta name="apple-mobile-web-app-status-bar-style" content="#141416">

		<?php wp_head() ?>

	</head>

	<body <?php body_class(); ?>>

		<?php wp_body_open(); ?>

		<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ghost-lite' ); ?></a>

		<?php

			if ( has_post_thumbnail()     &&     ( is_single() || is_page() )     &&
				get_theme_mod( 'post_single_bg_image_select_setting' ) == 'thumb' ) {

				$bgi = get_the_post_thumbnail_url();

			} else {

				$bgi_default = get_template_directory_uri() . '/img/page-default-bg.jpg';
				$bgi = esc_url(get_theme_mod( 'ghost_alt_background_image_setting', $bgi_default ));

			}

			$bgc = esc_attr(get_theme_mod( 'ghost_background_overlay_color_setting', '#000007' ));
			$bgo = esc_attr(get_theme_mod( 'ghost_background_overlay_opacity_setting', 70 ))/100;

		?>

		<div class="page__background" style="background-image: url('<?php echo $bgi ?>');">
			<div class="page__background__overlay" style="
				background-color: <?php echo $bgc; ?>;
				opacity: <?php echo $bgo; ?>;
			"></div>
		</div>

		<?php $is_top_cl = get_theme_mod( 'ghost_enable_top_bar_setting', false ) == true ? 'has__top__bar' : 'no__top__bar'; ?>
		<div class="main__wrapper <?php echo esc_attr($is_top_cl); ?>">

			<header class="header">
				<?php if ( get_theme_mod( 'ghost_enable_top_bar_setting', false ) ): ?>

					<div class="header__top__bar">
						<div class="container flx top__bar__container">

							<div class="header__top__bar__left flx">
								<?php if ( get_theme_mod( 'ghost_top_contact_or_text_setting', 'contact' ) == 'contact' ): ?>

									<?php if ( get_theme_mod( 'ghost_top_bar_email_text_setting', '' ) != '' ): ?>
										<span class="top__bar__contact<?php echo esc_attr(get_theme_mod( 'ghost_top_bar_email_show_setting', '' )); ?>">
											<span class="vissage-icon vissage-envelope"></span>
											<a href="mailto:<?php echo esc_attr(get_theme_mod( 'ghost_top_bar_email_text_setting', '' )); ?>"><?php echo esc_html(get_theme_mod( 'ghost_top_bar_email_text_setting', '' )); ?></a>
										</span>
									<?php endif; ?>

									<?php if ( get_theme_mod( 'ghost_top_bar_address_text_setting', '' ) != '' ): ?>
										<span class="top__bar__contact<?php echo esc_attr(get_theme_mod( 'ghost_top_bar_address_show_setting', '' )); ?>"><!-- hide_over_1025 -->
											<span class="vissage-icon vissage-location"></span>
											<?php echo esc_html(get_theme_mod( 'ghost_top_bar_address_text_setting', '' )) ?>
										</span>
									<?php endif; ?>

									<?php if ( get_theme_mod( 'ghost_top_bar_phone_text_setting', '' ) != '' ): ?>
										<span class="top__bar__contact<?php echo esc_attr(get_theme_mod( 'ghost_top_bar_phone_show_setting', '' )); ?>">
											<span class="vissage-icon vissage-phone"></span>
											<a href="tel:<?php echo str_replace(array(' ','(',')','-','/'), '', esc_html(get_theme_mod( 'ghost_top_bar_phone_text_setting', '' ))) ?>">
												<?php echo esc_attr(get_theme_mod( 'ghost_top_bar_phone_text_setting', '' )) ?>
											</a> 
										</span>
									<?php endif; ?>

								<?php else: ?>

									<p class="top__bar__left__text<?php echo esc_attr(get_theme_mod( 'ghost_top_bar_plain_text_show_setting', '' )); ?>"><?php echo esc_html(get_theme_mod( 'ghost_top_bar_plain_text_setting', '' )) ?></p>

								<?php endif; ?>
							</div><!-- /.header__top__bar__left -->

							<div class="header__top__bar__right flx">
								<div class="social__icons__container">

									<?php
										$soc_icons = array(
											'behance',
											'dribbble',
											'facebook',
											'github-alt',
											'instagram',
											'linkedin',
											'pinterest',
											'twitter',
											'youtube'
										);
									?>
									<?php foreach ( $soc_icons as $soc_icon ): if ( get_theme_mod( 'ghost_top_bar_'. $soc_icon .'_setting' ) != '' ): ?>
										<a href="<?php echo esc_url(get_theme_mod( 'ghost_top_bar_'. $soc_icon .'_setting', '' )) ?>">
											<span class="vissage-icon vissage-<?php echo esc_attr($soc_icon) ?>"></span>
										</a>
									<?php endif; endforeach; ?>

								</div>
							</div><!-- /.header__top__bar__right -->

						</div><!-- /.container.flx.top__bar__container -->
					</div><!-- /.header__top__bar -->

				<?php endif; ?>

				<div class="header__main be__sticky">
					<div class="container">
						<div class="header__inner__wrapper flx">
							<div class="icon__trigger mobile_trigger hide_over_1025">
								<span class="vissage-icon vissage-menu"></span>
								<span class="vissage-icon vissage-close"></span>
							</div>
							<div class="logo">
								<?php if ( !has_custom_logo() ): ?>
									<a href="<?php echo esc_url( home_url('/') ) ?>" rel="home"><?php echo esc_html(get_bloginfo('name')) ?></a>
									<?php if ( get_bloginfo( 'description' ) ): ?>
										<p class="site__description"><?php echo esc_html(get_bloginfo('description')) ?></p>
									<?php endif; ?>
								<?php else: ?>
									<?php the_custom_logo() ?>
								<?php endif; ?>
							</div>
							<?php wp_nav_menu( array(
								'theme_location'  => 'ghost-lite-main-menu',
								'container'       => 'nav',
								'container_class' => 'nav',
								'menu_class'      => 'menu flx',
								'fallback_cb'     => false
							) ); ?>

							<div class="header__widgets__wrapper">
								<button class="icon__trigger search__trigger">
									<span class="vissage-icon vissage-search"></span>
									<span class="vissage-icon vissage-close"></span>
								</button>
								<div class="search__container">
									<div class="container">
										<div class="search__content flx">
											<?php get_search_form() ?>
										</div>
									</div>
								</div>
							</div><!-- /.header__widgets__wrapper -->

						</div><!-- /.header__inner__wrapper -->
					</div>
				</div><!-- /.header__main -->
			</header>